@@ -211,8 +211,6 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent), key(" ")
   // setResizeMode must be called after all the columns are added
   nicknameListView->setResizeMode(KListView::LastColumn);
 
-//  nicknameListView->header()->setStretchEnabled(true,2);
-
   // separate LED from Text a little more
   nicknameListView->setColumnWidth(0, 10);
   nicknameListView->setColumnAlignment(0, Qt::AlignHCenter);
@@ -333,6 +331,7 @@ void Channel::setServer(Server *server) {
   ChatWindow::setServer(server);
   topicLine->setServer(server);
   refreshModeButtons();
+  setIdentity(server->getIdentity());
 
   connect(server->getOutputFilter(),SIGNAL(cycleChannel()),this,SLOT(cycleChannel()));
 }
@@ -1412,13 +1411,13 @@ void Channel::updateMode(QString sourceNick, char mode, bool plus, const QString
     case 'q':
       if(plus)
       {
-        if(fromMe) message=i18n("You set the channel mode to 'quiet'.");
-        else message=i18n("%1 sets the channel mode to 'quiet'.").arg(sourceNick);
+	if(fromMe) message=i18n("You set the channel mode to 'quiet' on %1.").arg(parameter);
+        else message=i18n("%1 sets the channel mode to 'quiet' on %2.").arg(sourceNick).arg(parameter);
       }
       else
       {
-        if(fromMe) message=i18n("You remove the 'quiet' channel mode.");
-        else message=i18n("%1 removes the 'quiet' channel mode.").arg(sourceNick);
+	if(fromMe) message=i18n("You remove the 'quiet' channel mode from %1.").arg(parameter);
+        else message=i18n("%1 removes the 'quiet' channel mode from %2.").arg(sourceNick).arg(parameter);
       }
 
     break;
@@ -1739,7 +1738,7 @@ void Channel::updateFonts()
       QString::null);
   }
 
-  nicknameListView->sort();
+  nicknameListView->resort();
 
   nicknameListView->setPaletteForegroundColor(fg);
   nicknameListView->setPaletteBackgroundColor(bg);
@@ -1968,6 +1967,8 @@ void Channel::serverQuit(const QString& reason)
 #ifdef USE_MDI
   ChannelNickPtr channelNick=m_server->getChannelNick(getName(),m_server->getNickname());
   if(channelNick)  removeNick(channelNick,reason,true);
+#else
+  Q_UNUSED(reason);
 #endif
 }
 
@@ -2166,4 +2167,15 @@ QString NickList::completeNick(const QString& pattern, bool& complete, QStringLi
   return QString::null;
 }
 
+void Channel::setIdentity(const Identity *newIdentity)
+{
+  if(!newIdentity) {
+    return;
+  }
+
+  ChatWindow::setIdentity(newIdentity);
+  nicknameCombobox->clear();
+  nicknameCombobox->insertStringList(newIdentity->getNicknameList());
+}
+
 #include "channel.moc"
