@@ -1,16 +1,30 @@
-// Konversation DCOP interface class
-// by Alex Zepeda, March 7, 2003
+/*
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+*/
 
-#include <kapp.h>
+/*
+  The konversation DCOP interface class
+  begin:     Mar 7 2003
+  copyright: (C) 2003 by Alex Zepeda
+  email:     zipzippy@sonic.net
+*/
+
+#include <kapplication.h>
 #include <kdebug.h>
 #include <dcopclient.h>
 
 #include <qstring.h>
+#include <klocale.h>
 
 #include "konversationapplication.h"
+#include "channel.h"
 #include "konvdcop.h"
 #include "identity.h"
 #include "ircevent.h"
+#include "server.h"
 
 KonvDCOP::KonvDCOP()
       : DCOPObject("Konversation"),
@@ -19,10 +33,19 @@ KonvDCOP::KonvDCOP()
   // reset hook counter
   hookId=0;
 
-  if(!kapp->dcopClient()->isRegistered())
+  KConfig *config = KGlobal::config();
+  config->setGroup("AutoAway");  //TODO - add this to preferences somewhere
+
+  if (config->readBoolEntry("UseAutoAway", true))
   {
-    kapp->dcopClient()->registerAs("konversation");
-    kapp->dcopClient()->setDefaultObject(objId());
+	  //disable for now until auto-available is working, and we prevent the user from changing nick _and_ setting away message
+//    connectDCOPSignal("kdesktop", "KScreensaverIface",
+//                      "KDE_start_screensaver()", "setAutoAway()", false);
+  }
+  else
+  {
+    disconnectDCOPSignal("kdesktop", "KScreensaverIface",
+    "KDE_start_screensaver()", "setAutoAway()");
   }
 }
 
@@ -30,7 +53,53 @@ void KonvDCOP::raw(const QString& server,const QString& command)
 {
   kdDebug() << "KonvDCOP::raw()" << endl;
   // send raw IRC protocol data
-  emit raw(server,command);
+  emit dcopRaw(server,command);
+}
+
+QStringList KonvDCOP::listServers()
+{
+  QStringList serverlist;
+  QPtrList<Server>servers = static_cast<KonversationApplication *>(kapp)->getServerList();
+  Server *server;
+  for ( server = servers.first(); server; server = servers.next() )
+    serverlist.append(server->getServerName());
+  return serverlist;
+}
+
+QStringList KonvDCOP::listConnectedServers()
+{
+  QStringList serverlist;
+  QPtrList<Server>servers = static_cast<KonversationApplication *>(kapp)->getServerList();
+  Server *server;
+  for ( server = servers.first(); server; server = servers.next() )
+    if(server->connected())
+      serverlist.append(server->getServerName());
+  return serverlist;
+}
+
+void KonvDCOP::setAway(const QString &awaymessage)
+{
+  if(awaymessage.isEmpty())
+    emit dcopMultiServerRaw("away " + i18n("Gone away for now."));  //away messages can't be empty.
+  else
+    emit dcopMultiServerRaw("away " + awaymessage);
+}
+void KonvDCOP::setAutoAway()
+{
+  kdDebug() << "set auto away" << endl;
+  emit dcopSetAutoAway();
+}
+void KonvDCOP::setBack()
+{
+  emit dcopMultiServerRaw("away");
+}
+void KonvDCOP::sayToAll(const QString &message)
+{
+  emit dcopMultiServerRaw("msg " + message);
+}
+void KonvDCOP::actionToAll(const QString &message)
+{
+  emit dcopMultiServerRaw("me " + message);
 }
 
 void KonvDCOP::say(const QString& server,const QString& target,const QString& command)
@@ -63,9 +132,9 @@ void KonvDCOP::insertRememberLine()
   emit dcopInsertRememberLine();
 }
 
-void KonvDCOP::connectToServer(const QString& url, int port)
+void KonvDCOP::connectToServer(const QString& url, int port, const QString& channel, const QString& password)
 {
-  emit dcopConnectToServer(url, port);
+  emit dcopConnectToServer(url, port, channel, password);
 }
 
 /*
@@ -106,19 +175,16 @@ void KonvDCOP::unregisterEventHook(int hookId)
   kdDebug() << "KonvDCOP::unregisterEventHook(): hook id " << hookId << " not found!" << endl;
 }
 
-bool KonvDCOP::isIgnore (int serverid, const QString &hostmask, Ignore::Type type)
+QString KonvDCOP::getNickname (const QString &server)
 {
-  return isIgnore(serverid, hostmask, static_cast<int>(type));
+  return static_cast<KonversationApplication *>(kapp)->getServerByName(server)->getNickname();
 }
 
-bool KonvDCOP::isIgnore (int /*serverid*/, const QString &/*hostmask*/, int /*type*/)
+QString KonvDCOP::getAnyNickname ()
 {
-  return false;
-}
-
-QString KonvDCOP::getNickname (int /*serverid*/)
-{
-  return QString::null;
+  const QPtrList<Server>serverlist = static_cast<KonversationApplication *>(kapp)->getServerList();
+  Server *server = serverlist.getFirst();
+  return server->getNickname();
 }
 
 // Identity stuff
@@ -126,28 +192,47 @@ KonvIdentDCOP::KonvIdentDCOP()
              : DCOPObject("KonvDCOPIdentity"),
                QObject(0, "KonvDCOPIdentity")
 {
-  if (!kapp->dcopClient()->isRegistered()) {
-    kapp->dcopClient()->registerAs("konversation");
-    kapp->dcopClient()->setDefaultObject(objId());
-  }
 }
 
-void KonvIdentDCOP::setrealName(const QString &/*identity*/, const QString& /*name*/)
+QStringList KonvIdentDCOP::listIdentities()
 {
+  QStringList identities;
+  QValueList<IdentityPtr> ids = KonversationApplication::preferences.getIdentityList();
+  for(QValueList<IdentityPtr>::iterator it = ids.begin(); it != ids.end(); ++it)
+  {
+    identities.append((*it)->getName());
+  }
+  return identities;
+}
+
+void KonvIdentDCOP::setrealName(const QString &id_name, const QString& name)
+{
+  QValueList<IdentityPtr> ids = KonversationApplication::preferences.getIdentityList();
+
+  for(QValueList<IdentityPtr>::iterator it = ids.begin(); it != ids.end(); ++it)
+  {
+    if ((*it)->getName() == id_name)
+    {
+      (*it)->setRealName(name);
+      return;
+    }
+  }
+
+
 }
 
 QString KonvIdentDCOP::getrealName(const QString &id_name)
 {
-  QPtrList<Identity> ids = KonversationApplication::preferences.getIdentityList();
+  QValueList<IdentityPtr> ids = KonversationApplication::preferences.getIdentityList();
 
-  Identity *identity;
-  for (identity = ids.first(); identity; identity = ids.next())
+  for(QValueList<IdentityPtr>::iterator it = ids.begin(); it != ids.end(); ++it)
   {
-    if (identity->getName()==id_name)
+    if ((*it)->getName() == id_name)
     {
-      return identity->getRealName();
+      return (*it)->getRealName();
     }
   }
+
   return QString::null;
 }
 
@@ -275,10 +360,6 @@ KonvPrefsDCOP::KonvPrefsDCOP ()
              : DCOPObject("KonvDCOPPreferences"),
                QObject(0, "KonvDCOPPreferences")
 {
-  if (!kapp->dcopClient()->isRegistered()) {
-    kapp->dcopClient()->registerAs("konversation");
-    kapp->dcopClient()->setDefaultObject(objId());
-  }
 }
 
 bool KonvPrefsDCOP::getAutoReconnect()
@@ -314,21 +395,6 @@ void KonvPrefsDCOP::setBeep(bool state)
   static_cast<KonversationApplication *>(kapp)->saveOptions(true);
 }
 
-void KonvPrefsDCOP::clearServerList()
-{
-  KonversationApplication::preferences.clearServerList();
-}
-
-void KonvPrefsDCOP::changeServerProperty(int id,int property,const QString& value)
-{
-  KonversationApplication::preferences.changeServerProperty(id, property, value);
-}
-
-void KonvPrefsDCOP::updateServer(int id,const QString& newDefinition)
-{
-  kdDebug() << "KonvPrefsDCOP::updateServer(" << id << "," << newDefinition << ")" << endl;
-}
-
 void KonvPrefsDCOP::setLog(bool state)
 {
   KonversationApplication::preferences.setLog(state);
@@ -447,15 +513,121 @@ QString KonvPrefsDCOP::getDccPath()
   return KonversationApplication::preferences.getDccPath();
 }
 
-void KonvPrefsDCOP::setDccRollback(unsigned long bytes)
+void KonvPrefsDCOP::setDccMethodToGetOwnIp(int methodId)
 {
-  KonversationApplication::preferences.setDccRollback(bytes);
+  KonversationApplication::preferences.setDccMethodToGetOwnIp(methodId);
   static_cast<KonversationApplication *>(kapp)->saveOptions(true);
 }
 
-unsigned long KonvPrefsDCOP::getDccRollback()
+int KonvPrefsDCOP::getDccMethodToGetOwnIp()
 {
-  return KonversationApplication::preferences.getDccRollback();
+  return KonversationApplication::preferences.getDccMethodToGetOwnIp();
+}
+
+void KonvPrefsDCOP::setDccSpecificOwnIp(const QString& ip)
+{
+  KonversationApplication::preferences.setDccSpecificOwnIp(ip);
+}
+
+QString KonvPrefsDCOP::getDccSpecificOwnIp()
+{
+  return KonversationApplication::preferences.getDccSpecificOwnIp();
+}
+
+void KonvPrefsDCOP::setDccSpecificSendPorts(bool state)
+{
+  KonversationApplication::preferences.setDccSpecificSendPorts(state);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+bool KonvPrefsDCOP::getDccSpecificSendPorts()
+{
+  return KonversationApplication::preferences.getDccSpecificSendPorts();
+}
+
+void KonvPrefsDCOP::setDccSendPortsFirst(unsigned long port)
+{
+  KonversationApplication::preferences.setDccSendPortsFirst(port);
+  if(KonversationApplication::preferences.getDccSendPortsLast() < port)
+    KonversationApplication::preferences.setDccSendPortsLast(port);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+unsigned long KonvPrefsDCOP::getDccSendPortsFirst()
+{
+  return KonversationApplication::preferences.getDccSendPortsFirst();
+}
+
+void KonvPrefsDCOP::setDccSendPortsLast(unsigned long port)
+{
+  KonversationApplication::preferences.setDccSendPortsLast(port);
+  if(port < KonversationApplication::preferences.getDccSendPortsFirst())
+    KonversationApplication::preferences.setDccSendPortsFirst(port);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+unsigned long KonvPrefsDCOP::getDccSendPortsLast()
+{
+  return KonversationApplication::preferences.getDccSendPortsLast();
+}
+
+void KonvPrefsDCOP::setDccSpecificChatPorts(bool state)
+{
+  KonversationApplication::preferences.setDccSpecificChatPorts(state);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+bool KonvPrefsDCOP::getDccSpecificChatPorts()
+{
+  return KonversationApplication::preferences.getDccSpecificChatPorts();
+}
+
+void KonvPrefsDCOP::setDccChatPortsFirst(unsigned long port)
+{
+  KonversationApplication::preferences.setDccChatPortsFirst(port);
+  if(KonversationApplication::preferences.getDccChatPortsLast() < port)
+    KonversationApplication::preferences.setDccChatPortsLast(port);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+unsigned long KonvPrefsDCOP::getDccChatPortsFirst()
+{
+  return KonversationApplication::preferences.getDccChatPortsFirst();
+}
+
+void KonvPrefsDCOP::setDccChatPortsLast(unsigned long port)
+{
+  KonversationApplication::preferences.setDccChatPortsLast(port);
+  if(port < KonversationApplication::preferences.getDccChatPortsFirst())
+    KonversationApplication::preferences.setDccChatPortsFirst(port);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+unsigned long KonvPrefsDCOP::getDccChatPortsLast()
+{
+  return KonversationApplication::preferences.getDccChatPortsLast();
+}
+
+void KonvPrefsDCOP::setDccFastSend(bool state)
+{
+  KonversationApplication::preferences.setDccFastSend(state);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+bool KonvPrefsDCOP::getDccFastSend()
+{
+  return KonversationApplication::preferences.getDccFastSend();
+}
+
+void KonvPrefsDCOP::setDccSendTimeout(int sec)
+{
+  KonversationApplication::preferences.setDccSendTimeout(sec);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+int KonvPrefsDCOP::getDccSendTimeout()
+{
+  return KonversationApplication::preferences.getDccSendTimeout();
 }
 
 void KonvPrefsDCOP::setBlinkingTabs(bool blink)
@@ -513,30 +685,35 @@ void KonvPrefsDCOP::setUseNotify(bool use)
   static_cast<KonversationApplication *>(kapp)->saveOptions(true);
 }
 
-QStringList KonvPrefsDCOP::getNotifyList()
+QMap<QString, QStringList> KonvPrefsDCOP::getNotifyList()
 {
   return KonversationApplication::preferences.getNotifyList();
 }
 
-QString KonvPrefsDCOP::getNotifyString()
+QStringList KonvPrefsDCOP::getNotifyListByGroup(QString groupName)
 {
-  return KonversationApplication::preferences.getNotifyString();
+  return KonversationApplication::preferences.getNotifyListByGroup(groupName);
 }
 
-void KonvPrefsDCOP::setNotifyList(QStringList newList)
+QString KonvPrefsDCOP::getNotifyStringByGroup(QString groupName)
+{
+  return KonversationApplication::preferences.getNotifyStringByGroup(groupName);
+}
+
+void KonvPrefsDCOP::setNotifyList(QMap<QString, QStringList> newList)
 {
   KonversationApplication::preferences.setNotifyList(newList);
   static_cast<KonversationApplication *>(kapp)->saveOptions(true);
 }
 
-bool KonvPrefsDCOP::addNotify(QString newPattern)
+bool KonvPrefsDCOP::addNotify(QString groupName, QString newPattern)
 {
-  return KonversationApplication::preferences.addNotify(newPattern);
+  return KonversationApplication::preferences.addNotify(groupName, newPattern);
 }
 
-bool KonvPrefsDCOP::removeNotify(QString pattern)
+bool KonvPrefsDCOP::removeNotify(QString groupName, QString pattern)
 {
-  return KonversationApplication::preferences.removeNotify(pattern);
+  return KonversationApplication::preferences.removeNotify(groupName, pattern);
 }
 
 void KonvPrefsDCOP::addIgnore(QString newIgnore)
@@ -597,4 +774,37 @@ bool KonvPrefsDCOP::getOSDUsage()
 	return KonversationApplication::preferences.getOSDUsage();
 }
 
+void KonvPrefsDCOP::setOSDOffsetX(int offset)
+{
+  KonversationApplication::preferences.setOSDOffsetX(offset);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+int KonvPrefsDCOP::getOSDOffsetX()
+{
+  return KonversationApplication::preferences.getOSDOffsetX();
+}
+
+void KonvPrefsDCOP::setOSDOffsetY(int offset)
+{
+  KonversationApplication::preferences.setOSDOffsetY(offset);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+int KonvPrefsDCOP::getOSDOffsetY()
+{
+  return KonversationApplication::preferences.getOSDOffsetY();
+}
+
+void KonvPrefsDCOP::setOSDAlignment(int alignment)
+{
+  KonversationApplication::preferences.setOSDAlignment(alignment);
+  static_cast<KonversationApplication *>(kapp)->saveOptions(true);
+}
+
+int KonvPrefsDCOP::getOSDAlignment()
+{
+  return KonversationApplication::preferences.getOSDAlignment();
+}
+
 #include "konvdcop.moc"
