@@ -13,6 +13,7 @@
 */
 
 #include "konversationmainwindow.h"
+#include "konvibookmarkhandler.h"
 
 #include <kaccel.h>
 #include <kstdaction.h>
@@ -123,30 +124,29 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
   KStdAction::keyBindings(this,SLOT(openKeyBindings()),actionCollection()); // options_configure_key_binding
   KAction *preferencesAction = KStdAction::preferences(this,SLOT(openPreferences()),actionCollection()); // options_configure
 
+  KAction* action;
+
   (new KAction(i18n("&Server List..."), "server", KShortcut("F2"), this, SLOT(openServerList()),
     actionCollection(), "open_server_list"))->setToolTip(i18n("Connect to a new server..."));
   (new KAction(i18n("Quick &Connect..."), "connect_creating", KShortcut("F7"), this, SLOT(openQuickConnectDialog()),
     actionCollection(), "quick_connect_dialog"))->setToolTip(i18n("Type in the address of a new IRC server to connect to..."));
 
-  new KAction(i18n("&Reconnect"), "connect_creating", 0, this, SLOT(reconnectCurrentServer()), actionCollection(), "reconnect_server");
+  action = new KAction(i18n("&Reconnect"), "connect_creating", 0, this, SLOT(reconnectCurrentServer()), actionCollection(), "reconnect_server");
+  action->setEnabled(false);
 
   (new KAction(i18n("&Identities..."), "identity", KShortcut("F8"), this, SLOT(openIdentitiesDialog()),
     actionCollection(), "identities_dialog"))->setToolTip(i18n("Set your nick, away message, etc..."));
 
   new KToggleAction(i18n("&Watched Nicks Online"), 0, KShortcut("F4"), this, SLOT(openNicksOnlinePanel()), actionCollection(), "open_nicksonline_window");
-  new KAction(i18n("&Open Logfile"), "history", KShortcut("Ctrl+O"), this, SLOT(openLogfile()), actionCollection(), "open_logfile");
+  action = new KAction(i18n("&Open Logfile"), "history", KShortcut("Ctrl+O"), this, SLOT(openLogfile()), actionCollection(), "open_logfile");
+  action->setEnabled(false);
 
-  new KAction(i18n("&Channel List"), 0, KShortcut("F5"), this, SLOT(openChannelList()), actionCollection(), "open_channel_list");
+  action = new KAction(i18n("&Channel List"), 0, KShortcut("F5"), this, SLOT(openChannelList()), actionCollection(), "open_channel_list");
+  action->setEnabled(false);
   new KToggleAction(i18n("&URL Catcher"), 0, KShortcut("F6"), this, SLOT(addUrlCatcher()), actionCollection(), "open_url_catcher");
 
   new KAction(i18n("&New Konsole"), "openterm", 0, this, SLOT(addKonsolePanel()), actionCollection(), "open_konsole");
 
-  m_kscript = new KScriptManager(this, "scriptmanager");
-  m_scriptMenu = new KActionMenu( i18n("&KDE Scripts"), actionCollection(), "scripts");
-  m_scriptMenu->setWhatsThis(i18n("This shows all available scripts and allows them to be executed."));
-  setupScripts();
-  connect( m_scriptMenu->popupMenu(), SIGNAL(activated( int)), this, SLOT(runScript( int )) );  
-  
   // Actions to navigate through the different pages
   KShortcut nextShortcut = KStdAccel::tabNext();
   nextShortcut.setSeq(1, KKeySequence("Alt+Right"));
@@ -169,20 +169,36 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
     tabSelectionMapper->setMapping( tabSelectionAction, i);
   }
   
-  new KAction(i18n("&Clear Window"),0,KShortcut("Ctrl+L"),this,SLOT(clearWindow()),actionCollection(),"clear_window");
+  action = new KAction(i18n("&Clear Window"),0,KShortcut("Ctrl+L"),this,SLOT(clearWindow()),actionCollection(),"clear_window");
+  action->setToolTip(i18n("Clear content of current window"));
+  action->setEnabled(false);
+  action = new KAction(i18n("Clear &All Windows"),0,KShortcut("CTRL+SHIFT+L"),this,SLOT(clearTabs()),actionCollection(),"clear_tabs");
+  action->setToolTip(i18n("Clear contents of all windows"));
+  action->setEnabled(false);
+
   KAction* awayAction = new KAction(i18n("Set &Away Globally")/*, "konversationaway"*/, KShortcut("Alt+A"),
     static_cast<KonversationApplication *>(kapp), SLOT(toggleAway()), actionCollection(),"toggle_away");  //string must be the same as that used in server.cpp
-  new KAction(i18n("&Join Channel..."), 0, KShortcut("Ctrl+J"), this, SLOT(showJoinChannelDialog()), actionCollection(), "join_channel");
+  awayAction->setEnabled(false);
+  action = new KAction(i18n("&Join Channel..."), 0, KShortcut("Ctrl+J"), this, SLOT(showJoinChannelDialog()), actionCollection(), "join_channel");
+  action->setEnabled(false);
 
-  KStdAction::find(this, SLOT(findText()), actionCollection());
-  KStdAction::findNext(this, SLOT(findNextText()), actionCollection());
+  action = KStdAction::find(this, SLOT(findText()), actionCollection());
+  action->setEnabled(false);
+  action = KStdAction::findNext(this, SLOT(findNextText()), actionCollection());
+  action->setEnabled(false);
 
-  (new KAction(i18n("&IRC Color..."), "colorize", CTRL+Key_K, this, SLOT(addIRCColor()), actionCollection(), "irc_colors"))->setToolTip(i18n("Set the color of your current IRC message."));
-  (new KAction(i18n("&Remember Line"), 0,  KShortcut("Ctrl+R") , this, SLOT(insertRememberLine()), actionCollection(), "insert_remember_line"))->setToolTip(i18n("Add a horizontal line that only you can see."));
-  (new KAction(i18n("Special &Character..."), "fonts", KShortcut("Alt+Shift+C"), this, SLOT(insertCharacter()), actionCollection(), "insert_character"))->setToolTip(i18n("Insert any character into your current IRC message. "));
+  action = new KAction(i18n("&IRC Color..."), "colorize", CTRL+Key_K, this, SLOT(addIRCColor()), actionCollection(), "irc_colors");
+  action->setToolTip(i18n("Set the color of your current IRC message."));
+  action->setEnabled(false);
+  action = new KAction(i18n("&Remember Line"), 0,  KShortcut("Ctrl+R") , this, SLOT(insertRememberLine()), actionCollection(), "insert_remember_line");
+  action->setToolTip(i18n("Add a horizontal line that only you can see."));
+  action->setEnabled(false);
+  action = new KAction(i18n("Special &Character..."), "char", KShortcut("Alt+Shift+C"), this, SLOT(insertCharacter()), actionCollection(), "insert_character");
+  action->setToolTip(i18n("Insert any character into your current IRC message. "));
+  action->setEnabled(false);
 
   new KAction(i18n("Close &All Open Queries"), 0, KShortcut("F11"), this, SLOT(closeQueries()), actionCollection(), "close_queries");
-
+  
 #ifdef USE_MDI
   new KAction(i18n("Tabpage Mode"),"tabpage",0,this,SLOT (switchToTabPageMode()),actionCollection(),"mdi_tabpage_mode");
   new KAction(i18n("Toplevel Mode"),"toplevel",0,this,SLOT (switchToToplevelMode()),actionCollection(),"mdi_toplevel_mode");
@@ -244,6 +260,10 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
   createGUI();
 #endif
 
+  // Bookmarks
+  m_bookmarkHandler = new KonviBookmarkHandler(this);
+  connect(m_bookmarkHandler,SIGNAL(openURL(const QString&,const QString&)),this,SLOT(openURL(const QString&,const QString&)));
+
   resize(700, 500);  // Give the app a sane default size
   setAutoSaveSettings();
   showMenuBarAction->setChecked(KonversationApplication::preferences.getShowMenuBar());
@@ -268,67 +288,6 @@ KonversationMainWindow::~KonversationMainWindow()
 {
   deleteDccPanel();
   delete dccTransferHandler;
-  delete m_kscript;
-}
-
-void KonversationMainWindow::setupScripts()
-{
-  // locate all scripts, local as well as global.
-  // The script manager will do the nessecary sanity checking
-  QStringList scripts = KGlobal::dirs()->findAllResources("data", QString(kapp->name())+"/scripts/*.desktop", false, true );
-  for (QStringList::Iterator it = scripts.begin(); it != scripts.end(); ++it )
-    m_kscript->addScript( *it );
-  QStringList l ( m_kscript->scripts() );
-  for (QStringList::Iterator it=l.begin(); it != l.end(); ++it )
-    m_scriptMenu->popupMenu()->insertItem( *it );
-  
-  // Auto-alias scripts
-/*  QStringList scripts = KGlobal::dirs()->findAllResources("data","konversation/scripts/ *");
-  QFileInfo* fileInfo = new QFileInfo();
-  QStringList aliasList(KonversationApplication::preferences.getAliasList());
-  QString newAlias;
-
-  for ( QStringList::Iterator it = scripts.begin(); it != scripts.end(); ++it ) {
-    fileInfo->setFile( *it );
-  if ( fileInfo->isExecutable() ) {
-    newAlias = (*it).section('/',-1)+" "+"/exec "+(*it).section('/', -1 );
-    if(!aliasList.contains(newAlias))
-      aliasList.append(newAlias);
-  }*/
-//}
-//  KonversationApplication::preferences.setAliasList(aliasList);
-}
-
-void KonversationMainWindow::runScript(const QString &destination, const QString &scriptname )
-{
-  if(!frontServer) return; 
-
-  QStringList arguments;
-  arguments << frontServer->getServerName();
-  arguments << destination;
-
-#if KDE_IS_VERSION(3,3,92)  
-  m_kscript->runScript( scriptname, 0, arguments );
-#else // Don't crash for kdelibs < 3.3.92
-  if( m_kscript->scripts().contains( scriptname ) )
-    m_kscript->runScript( scriptname, 0, arguments );
-#endif
-
-}
-
-void KonversationMainWindow::runScript( int mIId )
-{
-  if(!frontServer) return;
-  kdDebug() << "Starting script engine..." << endl;
-  kdDebug()<<"runScript( "<<mIId<<" ) ["<<m_scriptMenu->popupMenu()->text( mIId )<<"]"<<endl;
-  QStringList arguments;
-  arguments << kapp->dcopClient()->appId();
-  arguments << frontServer->getServerName();
-  arguments << m_frontView->getName();
-  
-  kdDebug() << "with parameters " <<  frontServer->getServerName() << " and " << m_frontView->getName() << endl;
-  
-  m_kscript->runScript( m_scriptMenu->popupMenu()->text( mIId ), 0, arguments );
 }
 
 void KonversationMainWindow::switchToTabPageMode()
@@ -1039,6 +998,8 @@ void KonversationMainWindow::updateFrontView()
 #else
   ChatWindow* view = static_cast<ChatWindow*>(getViewContainer()->currentPage());
 #endif
+  KAction* action;
+
   if(view) {
     // Make sure that only views with info output get to be the m_frontView
     if(m_frontView) {
@@ -1062,6 +1023,100 @@ void KonversationMainWindow::updateFrontView()
     if(view->searchView()) {
       searchView = view;
     }
+
+    action = actionCollection()->action("insert_remember_line");
+    if(action) action->setEnabled(view->getTextView() != 0);
+
+    action = actionCollection()->action("insert_character");
+    if(action) action->setEnabled(view->isInsertCharacterSupported());
+
+    action = actionCollection()->action("irc_colors");
+    if(action) action->setEnabled(view->areIRCColorsSupported());
+
+    action = actionCollection()->action("clear_window");
+    if(action) action->setEnabled(view->getTextView() != 0);
+
+    action = actionCollection()->action("edit_find");
+    if(action) action->setEnabled(view->searchView());
+
+    action = actionCollection()->action("edit_find_next");
+    if(action) action->setEnabled(view->searchView());
+
+    action = actionCollection()->action("open_channel_list");
+    if(action) {
+      if(view->getServer()) {
+        action->setEnabled(true);
+        action->setText(i18n("&Channel List for %1").arg(view->getServer()->getServerGroup()));
+      } else {
+        action->setEnabled(false);
+        action->setText(i18n("&Channel List"));
+      }
+    }
+
+    action = actionCollection()->action("join_channel");
+    if(action) action->setEnabled(view->getServer() != 0);
+
+    action = actionCollection()->action("open_logfile");
+    if(action) {
+      action->setEnabled(!view->logFileName().isEmpty());
+      if(view->logFileName().isEmpty())
+        action->setText(i18n("&Open Logfile"));
+      else
+        action->setText(i18n("&Open Logfile for %1").arg(view->getName()));
+    }
+
+    action = actionCollection()->action("clear_tabs");
+    if(action) action->setEnabled(true);
+
+    action = actionCollection()->action("toggle_away");
+    if(action) action->setEnabled(true);
+
+    action = actionCollection()->action("reconnect_server");
+    if(action) {
+      Server* server = view->getServer();
+
+      if(server && !server->isConnected()) {
+        action->setEnabled(true);
+      } else {
+        action->setEnabled(false);
+      }
+    }
+  } else {
+    action = actionCollection()->action("insert_remember_line");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("insert_character");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("irc_colors");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("clear_window");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("clear_tabs");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("edit_find");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("edit_find_next");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("open_channel_list");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("open_logfile");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("toggle_away");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("join_channel");
+    if(action) action->setEnabled(false);
+
+    action = actionCollection()->action("reconnect_server");
+    if(action) action->setEnabled(false);
   }
 }
 #ifdef USE_MDI
@@ -1531,6 +1586,20 @@ void KonversationMainWindow::closeQueries()
 #endif
 }
 
+void KonversationMainWindow::clearTabs()
+{
+  int total=getViewContainer()->count()-1;
+  ChatWindow* nextPage;
+
+  for(int i=0;i<=total;i++)
+    {
+      nextPage=static_cast<ChatWindow*>(getViewContainer()->page(i));
+
+      if(nextPage && nextPage->getTextView())
+	nextPage->getTextView()->clear();
+    }
+}
+
 bool KonversationMainWindow::event(QEvent* e)
 {
 #ifndef USE_MDI
@@ -1646,7 +1715,7 @@ void KonversationMainWindow::showJoinChannelDialog()
     return;
   }
 
-  Konversation::JoinChannelDialog dlg(frontServer->getServerGroup(), this);
+  Konversation::JoinChannelDialog dlg(frontServer, this);
 
   if(dlg.exec() == QDialog::Accepted) {
     frontServer->sendJoinCommand(dlg.channel(), dlg.password());
@@ -1660,4 +1729,66 @@ void KonversationMainWindow::reconnectCurrentServer()
   }
 }
 
+void KonversationMainWindow::openURL(const QString&url, const QString&/* title*/)
+{
+  QString nUrl = url;
+  
+  QString serverAndPort = nUrl.remove("irc://").section('/',0,0);
+  QString channelAndPassword = nUrl.section('/',1,1);
+
+  QString server = serverAndPort.section(':',0,0);
+  QString port = serverAndPort.section(':',1,1);
+
+  QString channel = channelAndPassword.section('?',0,0);
+  QString password = channelAndPassword.section('?',1,1);
+  
+  if(port.isEmpty())
+    port = "6667";
+
+  KonversationApplication::instance()->dcopConnectToServer(server,port.toInt(),channel,password);
+  
+}
+
+QString KonversationMainWindow::currentURL()
+{
+  QString url = QString::null;
+  QString channel = QString::null;
+
+  if(frontServer && m_frontView)
+    {
+      updateFrontView();
+      
+      if(m_frontView->getType() == ChatWindow::Channel)
+	channel = m_frontView->getName();
+
+      url = "irc://"+frontServer->getServerName()+":"+QString::number(frontServer->getPort())+"/"+channel;
+    }
+  
+  return url;
+}
+
+QString KonversationMainWindow::currentTitle()
+{
+  if(frontServer)
+    {
+      return frontServer->getServerName();
+    }
+  else
+    return QString::null;
+}
+
+void KonversationMainWindow::serverStateChanged(Server* server, Server::State state)
+{
+  KAction* action = actionCollection()->action("reconnect_server");
+
+  if(action && (frontServer == server)) {
+
+    if(state != Server::SSDisconnected) {
+      action->setEnabled(false);
+    } else {
+      action->setEnabled(true);
+    }
+  }
+}
+
 #include "konversationmainwindow.moc"
