@@ -34,6 +34,7 @@
 #include "preferences.h"
 #include "ssllabel.h"
 #include "nickinfo.h"
+#include "server.h"
 
 /*
  Dario Abatianni
@@ -44,7 +45,7 @@ class KMdiChildView; // USE_MDI
 class KActionMenu;
 class KScriptManager;
 
-class Server;
+class KonviBookmarkHandler;
 class StatusPanel;
 class ChatWindow;
 class Channel;
@@ -100,12 +101,15 @@ class KonversationMainWindow : public MAIN_TYPE // USE_MDI
     void updateFonts();
     void updateTabPlacement();
     
-    void runScript(const QString &destination, const QString &scriptname );
-
     Konversation::TrayIcon* systemTrayIcon() const { return tray; }
 
     ChatWindow* frontView() { return m_frontView; }
 
+
+    // Bookmark related functions
+    QString currentURL();
+    QString currentTitle();
+
   signals:
     void prefsChanged();
     void startNotifyTimer(int msec);
@@ -147,6 +151,8 @@ class KonversationMainWindow : public MAIN_TYPE // USE_MDI
     void openServerList();
     void openIdentitiesDialog();
 
+    void serverStateChanged(Server* server, Server::State state);
+
   protected slots:
     void openPreferences();
     void openKeyBindings();
@@ -194,6 +200,7 @@ class KonversationMainWindow : public MAIN_TYPE // USE_MDI
     void addIRCColor();
     void clearWindow();
     void closeQueries();
+    void clearTabs();
 
     void insertCharacter();
     void insertChar(const QChar& chr);
@@ -202,10 +209,10 @@ class KonversationMainWindow : public MAIN_TYPE // USE_MDI
 
     void showJoinChannelDialog();
     
-    void runScript( int menuItemId);
-
     void reconnectCurrentServer();
 
+    void openURL(const QString& url, const QString& title);
+
   protected:
     enum StatusID
     {
@@ -228,8 +235,6 @@ class KonversationMainWindow : public MAIN_TYPE // USE_MDI
     virtual bool event(QEvent* e);
     virtual void resizeEvent(QResizeEvent* ev);
     
-    void setupScripts();
-    
 #ifdef USE_MDI
 #else
     LedTabWidget* getViewContainer();
@@ -257,14 +262,14 @@ class KonversationMainWindow : public MAIN_TYPE // USE_MDI
 
     bool m_closeApp;
     
-    KActionMenu *m_scriptMenu;
-    KScriptManager* m_kscript;
-		
     SSLLabel* m_sslLabel;
     QLabel* m_channelInfoLabel;
 
     Konversation::InsertCharDialog* m_insertCharDialog;
     Konversation::ServerListDialog* m_serverListDialog;
+
+    KPopupMenu* m_bookmarks;
+    KonviBookmarkHandler* m_bookmarkHandler;
 };
 
 #endif
