@@ -22,6 +22,7 @@
 #include <kuser.h>
 
 #include <qpalette.h>
+#include <qregexp.h>
 
 #include "preferences.h"
 #include "prefsdialog.h"
@@ -60,15 +61,15 @@ Preferences::Preferences()
   setNickCompleteSuffixStart(": ");
   setNickCompleteSuffixMiddle(" ");
 
-  Konversation::ServerGroupSettings serverGroup;
-  serverGroup.setName("Freenode");
+  Konversation::ServerGroupSettingsPtr serverGroup = new Konversation::ServerGroupSettings;
+  serverGroup->setName("Freenode");
   Konversation::ServerSettings server;
   server.setServer("irc.freenode.org");
-  serverGroup.addServer(server);
-  serverGroup.setIdentityId(identity->id());
+  serverGroup->addServer(server);
+  serverGroup->setIdentityId(identity->id());
   Konversation::ChannelSettings channel;
   channel.setName("#kde");
-  serverGroup.addChannel(channel);
+  serverGroup->addChannel(channel);
   m_serverGroupList.append(serverGroup);
 
   buttonList.append("Op,/OP %u%n");
@@ -106,7 +107,6 @@ Preferences::Preferences()
   setBeep(false);
   setRawLog(false);
 
-  setVersionReply(QString::null); //XXX is this really necessary?
   setDccPath(user.homeDir()+"/dccrecv");
   setDccAddPartner(false);
   setDccCreateFolder(false);
@@ -133,6 +133,8 @@ Preferences::Preferences()
   setAutoWhoContinuousEnabled(true);
   setAutoWhoContinuousInterval(90);
 
+  setShowRealNames(false);
+
   setLog(true);
   setLowerLog(true);
   setAddHostnameToLog(false);
@@ -185,8 +187,7 @@ Preferences::Preferences()
   setOpValue(4);
   setHalfopValue(8);
   setVoiceValue(16);
-  setAwayValue(32);
-  setNoRightsValue(64);
+  setNoRightsValue(32);
 
   setSortCaseInsensitive(true);
   setSortByStatus(false);
@@ -266,26 +267,26 @@ void Preferences::setServerGroupList(const Konversation::ServerGroupList& list)
   m_serverGroupList = list;
 }
 
-void Preferences::addServerGroup(const Konversation::ServerGroupSettings& serverGroup)
+void Preferences::addServerGroup(Konversation::ServerGroupSettingsPtr serverGroup)
 {
   m_serverGroupList.append(serverGroup);
 }
 
-const Konversation::ServerGroupSettings Preferences::serverGroupById(int id)
+const Konversation::ServerGroupSettingsPtr Preferences::serverGroupById(int id)
 {
   if(!m_serverGroupList.count()) {
-    return Konversation::ServerGroupSettings();
+    return 0;
   }
   
   Konversation::ServerGroupList::iterator it;
   
   for(it = m_serverGroupList.begin(); it != m_serverGroupList.end(); ++it) {
-    if((*it).id() == id) {
+    if((*it)->id() == id) {
       return (*it);
     }
   }
 
-  return Konversation::ServerGroupSettings();
+  return 0;
 }
 
 void Preferences::removeServerGroup(int id)
@@ -297,7 +298,7 @@ void Preferences::removeServerGroup(int id)
   Konversation::ServerGroupList::iterator it;
   
   for(it = m_serverGroupList.begin(); it != m_serverGroupList.end(); ++it) {
-    if((*it).id() == id) {
+    if((*it)->id() == id) {
       m_serverGroupList.remove(it);
       return;
     }
@@ -379,6 +380,10 @@ const bool Preferences::getAutoWhoContinuousEnabled() { return autoWhoContinuous
 void Preferences::setAutoWhoContinuousInterval(int interval) { autoWhoContinuousInterval=interval; }
 const int Preferences::getAutoWhoContinuousInterval() { return autoWhoContinuousInterval; }
 
+
+const bool Preferences::getShowRealNames() { return showRealNames;}
+void Preferences::setShowRealNames(bool show) { showRealNames=show; }
+
 void Preferences::setDccAddPartner(bool state) { dccAddPartner=state; }
 const bool Preferences::getDccAddPartner() { return dccAddPartner; }
 
@@ -471,12 +476,10 @@ const bool Preferences::getBeep() { return beep; }
 void Preferences::setRawLog(bool state) { rawLog=state; }
 const bool Preferences::getRawLog() { return rawLog; }
 
-void Preferences::setVersionReply(const QString &reply) { versionReply = reply; }
-
-const QString Preferences::getVersionReply() const
-{
-  return versionReply;
-}
+void Preferences::setCustomVersionReplyEnabled(bool state) { customVersionReplyEnabled=state; }
+const bool Preferences::getCustomVersionReplyEnabled() { return customVersionReplyEnabled; }
+void Preferences::setCustomVersionReply(const QString &reply) { customVersionReply=reply; }
+QString Preferences::getCustomVersionReply() { return customVersionReply; }
 
 const int Preferences::getNotifyDelay() { return notifyDelay; }
 void Preferences::setNotifyDelay(int delay) { notifyDelay=delay; }
@@ -618,8 +621,6 @@ const bool Preferences::getBringToFront() { return bringToFront; }
 
 void Preferences::setCommandChar(const QString &newCommandChar) { commandChar=newCommandChar; }
 const QString Preferences::getCommandChar() { return commandChar; }
-void Preferences::setPreShellCommand(const QString& command) { preShellCommandStr=command; }
-const QString Preferences::getPreShellCommand() { return preShellCommandStr; }
 
 // TODO: Make this a little simpler (use an array and enum)
 //       get/set message font colors
@@ -849,7 +850,6 @@ void Preferences::setOwnerValue(int value)           { ownerValue=value; }
 void Preferences::setOpValue(int value)              { opValue=value; }
 void Preferences::setHalfopValue(int value)          { halfopValue=value; }
 void Preferences::setVoiceValue(int value)           { voiceValue=value; }
-void Preferences::setAwayValue(int value)            { awayValue=value; }
 void Preferences::setNoRightsValue(int value)        { noRightsValue=value; }
 
 const int Preferences::getAdminValue()                     { return adminValue; }
@@ -857,7 +857,6 @@ const int Preferences::getOwnerValue()                     { return ownerValue;
 const int Preferences::getOpValue()                        { return opValue; }
 const int Preferences::getHalfopValue()                    { return halfopValue; }
 const int Preferences::getVoiceValue()                     { return voiceValue; }
-const int Preferences::getAwayValue()                      { return awayValue; }
 const int Preferences::getNoRightsValue()                  { return noRightsValue; }
 
 void Preferences::setSortCaseInsensitive(bool state) { sortCaseInsensitive=state; }
